@@ -1,4 +1,4 @@
-/*  $Id: ckpasswd.c,v 1.6.2.1 2000/04/18 22:01:07 kondou Exp $
+/*  $Id: ckpasswd.c,v 1.6.2.3 2001/07/19 21:28:13 rra Exp $
 **
 **  The default username/password authenticator.
 */
@@ -14,11 +14,13 @@
 # include <fcntl.h>
 #endif
 
-#ifdef HAVE_NDBM_H
-# include <ndbm.h>
-#else
-# ifdef HAVE_DB1_NDBM_H
-#  include <db1/ndbm.h>
+#if HAVE_DBM
+# ifdef HAVE_NDBM_H
+#  include <ndbm.h>
+# else
+#  ifdef HAVE_DB1_NDBM_H
+#   include <db1/ndbm.h>
+#  endif
 # endif
 #endif
 
@@ -72,14 +74,13 @@ char *GetFilePass(char *name, char *file)
     if (!found)
 	return(0);
     iter = colon+1;
-    if (!(colon = strchr(iter, ':')))
-	return(0);
-    *colon = 0;
+    if (colon = strchr(iter, ':'))
+	*colon = 0;
     strcpy(pass, iter);
     return(pass);
 }
 
-#if defined(HAVE_NDBM_H) || defined(HAVE_DB1_NDBM_H)
+#if HAVE_DBM
 char *GetDBPass(char *name, char *file)
 {
     datum key;
@@ -102,7 +103,7 @@ char *GetDBPass(char *name, char *file)
     dbm_close(D);
     return(pass);
 }
-#endif
+#endif /* HAVE_DBM */
 
 int main(int argc, char *argv[])
 {
@@ -118,17 +119,17 @@ int main(int argc, char *argv[])
     do_shadow = do_file = do_db = 0;
     fname = 0;
 #if HAVE_GETSPNAM
-#if defined(HAVE_NDBM_H) || defined(HAVE_DB1_NDBM_H)
+# if HAVE_DBM
     while ((opt = getopt(argc, argv, "sf:d:")) != -1) {
-#else
+# else
     while ((opt = getopt(argc, argv, "sf:")) != -1) {
-#endif
+# endif
 #else
-#if defined(HAVE_NDBM_H) || defined(HAVE_DB1_NDBM_H)
+# if HAVE_DBM
     while ((opt = getopt(argc, argv, "f:d:")) != -1) {
-#else
+# else
     while ((opt = getopt(argc, argv, "f:")) != -1) {
-#endif
+# endif
 #endif
 	/* only allow one of the three possibilities */
 	if (do_shadow || do_file || do_db)
@@ -141,7 +142,7 @@ int main(int argc, char *argv[])
 	    fname = optarg;
 	    do_file = 1;
 	    break;
-#if defined(HAVE_NDBM_H) || defined(HAVE_DB1_NDBM_H)
+#if HAVE_DBM
 	  case 'd':
 	    fname = optarg;
 	    do_db = 1;
@@ -182,7 +183,7 @@ int main(int argc, char *argv[])
     if (do_file)
 	rpass = GetFilePass(uname, fname);
     else
-#if defined(HAVE_NDBM_H) || defined(HAVE_DB1_NDBM_H)
+#if HAVE_DBM
     if (do_db)
 	rpass = GetDBPass(uname, fname);
     else
