@@ -1,4 +1,4 @@
-/*  $Id: makehistory.c,v 1.74.2.7 2000/08/09 22:09:02 kondou Exp $
+/*  $Id: makehistory.c,v 1.74.2.9 2001/03/26 22:37:45 kondou Exp $
 **
 **  Rebuild history/overview databases.
 */
@@ -623,7 +623,10 @@ DoArt(ARTHANDLE *art)
 	if (!SMprobe(SMARTNGNUM, art->token, (void *)&ann)) {
 	    Xrefp->Header = NULL;
 	    Xrefp->HeaderLength = 0;
-	}
+	} else
+	    return;
+	if (ann.artnum == 0)
+	    return;
 	len = strlen(XREF) + 1 + strlen(innconf->pathhost) + 1 + strlen(ann.groupname) + 1 + 16 + 1;
 	if (len > BIG_BUFFER) {
 	    Xrefp->Header = NULL;
@@ -736,7 +739,7 @@ DoArt(ARTHANDLE *art)
 void
 Usage(void)
 {
-    fprintf(stderr, "Usage: makehistory [-b] [-f file] [-O] [-I] [-l overtmpsegsize [-a] [-u] [-x] [-T tmpdir]\n");
+    fprintf(stderr, "Usage: makehistory [-b] [-f file] [-O] [-I] [-l overtmpsegsize [-a] [-x] [-T tmpdir]\n");
     fprintf(stderr, "\t-b -- delete bad articles from spool\n");
     fprintf(stderr, "\t-e -- read entire articles to compute proper Bytes headers\n");
     fprintf(stderr, "\t-f -- write history entries to file (default $pathdb/history)\n");
@@ -744,7 +747,6 @@ Usage(void)
     fprintf(stderr, "\t-O -- create overview entries for articles\n");
     fprintf(stderr, "\t-I -- do not create overview entries for articles below lowmark in active\n");
     fprintf(stderr, "\t-l nnn -- set size of batches too do overview updates in (default 10000)\n");
-    fprintf(stderr, "\t-u -- 'update mode' assume server running, only output to file\n");
     fprintf(stderr,"\t\tentries not already in main history file.\n");
     fprintf(stderr, "\t-x -- don't bother writing any history entries at all\n");
     fprintf(stderr, "\t-T tmpdir -- use directory tmpdir for temp files. \n");
