@@ -11,12 +11,11 @@
 **  Got that?  All the remaining work in this program is to get the
 **  ending conditions right.
 */
-
-#include "config.h"
+#include <stdio.h>
+#include <sys/types.h>
+#include "configdata.h"
 #include "clibrary.h"
 
-#include "inn/messages.h"
-
 
 /*
 **  These characters can't appear in normal output, so we use them to
@@ -33,16 +32,18 @@ static int	count;
 
 
 static void
-pack6(int n, int last)
+pack6(n, last)
+    register int	n;
+    int			last;
 {
-    char	*q;
-    int	i;
+    register char	*q;
+    register int	i;
     char		b3[3];
 
     i = 3;
     if (last && (i = Buffer[n - 1]) >= 3) {
 	/* Do the best we can. */
-        warn("badly-terminated file");
+	(void)fprintf(stderr, "Badly-terminated file.\n");
 	i = 3;
     }
 
@@ -50,17 +51,20 @@ pack6(int n, int last)
     b3[1] = (Buffer[1] << 4) | ((Buffer[2] >> 2) & 0x0F);
     b3[2] = (Buffer[2] << 6) | ( Buffer[3]       & 0x3F);
     for (q = b3; --i >= 0; )
-	putchar(*q++);
+	(void)putchar(*q++);
 }
 
 
 static void
-pack12(char *p, int n, int last)
+pack12(p, n, last)
+    register char	*p;
+    register int	n;
+    int			last;
 {
-    char	*q;
-    int	c13;
-    int	c;
-    int	i;
+    register char	*q;
+    register int	c13;
+    register int	c;
+    register int	i;
     char		b13[13];
     char		b3[3];
 
@@ -84,9 +88,9 @@ pack12(char *p, int n, int last)
 	    b3[0] = (Buffer[0] << 2) | ((Buffer[1] >> 4) & 0x03);
 	    b3[1] = (Buffer[1] << 4) | ((Buffer[2] >> 2) & 0x0F);
 	    b3[2] = (Buffer[2] << 6) | ( Buffer[3]       & 0x3F);
-	    putchar(b3[0]);
-	    putchar(b3[1]);
-	    putchar(b3[2]);
+	    (void)putchar(b3[0]);
+	    (void)putchar(b3[1]);
+	    (void)putchar(b3[2]);
 	    i = 0;
 	    q = Buffer;
 	}
@@ -108,21 +112,21 @@ pack12(char *p, int n, int last)
 int
 main(void)
 {
-    int	c;
-    char	*p;
-    int	i;
-    int	first;
-    int	cnt;
+    register int	c;
+    register char	*p;
+    register int	i;
+    register int	first;
+    register int	cnt;
     char		*base;
     char		b12[12];
     char		c12[12];
 
-    message_program_name = "decode";
-
     base = p = b12;
     for (i = 12, cnt = 0, first = 1; (c = getchar()) != EOF; ) {
-	if (c < ' ' || c >= ' ' + 91)
-            die("bad data");
+	if (c < ' ' || c >= ' ' + 91) {
+	    (void)fprintf(stderr, "decode: Bad data\n");
+	    exit(1);
+	}
 	if (i == 10 && p[-1] == ENDMARK1 && p[-2] == ENDMARK2) {
 	    cnt = c - ' ';
 	    i = 12;
