@@ -1,4 +1,4 @@
-/*  $Id: libinn.h,v 1.74.2.3 2000/09/30 01:03:44 hkehoe Exp $
+/*  $Id: libinn.h,v 1.74.2.4 2002/03/25 19:48:43 rra Exp $
 **
 **  Here be declarations of functions in the InterNetNews library.
 */
@@ -260,8 +260,9 @@ extern int	getfdcount(void);
 extern int	wildmat(const char *text, const char *p);
 extern pid_t	waitnb(int *statusp);
 extern int	xread(int fd, char *p, OFFSET_T i);
-extern int	xwrite(int fd, char *p, int i);
-extern int	xwritev(int fd, struct iovec *vp, int vpcount);
+extern ssize_t  xpwrite(int fd, const void *buffer, size_t size, off_t offset);
+extern ssize_t  xwrite(int fd, const void *buffer, size_t size);
+extern ssize_t  xwritev(int fd, const struct iovec *iov, int iovcnt);
 extern int	GetResourceUsage(double *usertime, double *systime);
 extern int	SetNonBlocking(int fd, BOOL flag);
 extern void	CloseOnExec(int fd, int flag);
