@@ -1,10 +1,13 @@
-/*  $Revision: 1.3 $
+/*  $Revision: 1.4.2.1 $
 **
 **  Quick I/O package -- optimized for reading through a file.
 */
 
 #include <storage.h>
 
+#ifdef __cplusplus
+extern "C" {   
+#endif /* __cplusplus */
 
 /*
 **  State for a quick open file.
@@ -17,7 +20,7 @@ typedef struct _QIOSTATE {
     char	*Buffer;
     char	*End;
     char	*Start;
-    long	Count;          /* Number of bytes read so far */
+    OFFSET_T	Count;          /* Number of bytes read so far */
     int         WireFormat;
     ARTHANDLE   *handle;        /* Storage API handle for the open article */
 } QIOSTATE;
@@ -41,3 +44,7 @@ extern QIOSTATE	*QIOfdopen(const int fd);
 extern char	*QIOread(QIOSTATE *qp);
 extern void	QIOclose(QIOSTATE *qp);
 extern int	QIOrewind(QIOSTATE *qp);
+
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
