@@ -1,33 +1,33 @@
-/*  $Id: proc.c 9904 2015-06-20 17:23:51Z iulius $
+/*  $Id: proc.c,v 1.6 1999/10/27 10:17:37 rra Exp $
 **
 **  Process control routines.
 */
-
-#include "config.h"
+#include <stdio.h>
+#include <sys/types.h>
+#include <netinet/in.h>
+#include "configdata.h"
 #include "clibrary.h"
-#include <sys/wait.h>
-
 #include "innd.h"
 
 
-static PROCESS	*PROCtable;
-static int	PROCtablesize;
-static PROCESS	PROCnull = { PSfree, 0, 0, 0, 0, 0 };
+STATIC PROCESS	*PROCtable;
+STATIC int	PROCtablesize;
+STATIC PROCESS	PROCnull = { PSfree };
 
 
 /*
 **  Collect dead processes.
 */
-static void
-PROCreap(void)
+STATIC void
+PROCreap()
 {
-    int		status;
-    PROCESS	*pp;
-    int         i;
-    pid_t	pid;
+    int			status;
+    register PROCESS	*pp;
+    register int	i;
+    register PID_T	pid;
 
     for ( ; ; ) {
-	pid = waitpid(-1, &status, WNOHANG);
+	pid = waitnb(&status);
 	if (pid == 0)
 	    break;
 	if (pid < 0) {
@@ -36,31 +36,25 @@ PROCreap(void)
 	    break;
 	}
 	for (pp = PROCtable, i = PROCtablesize; --i >= 0; pp++)
-            if (pp->State == PSrunning && pp->Pid == pid) {
-		PROCneedscan = true;
-		pp->Status = WEXITSTATUS(status);
+	    if (pp->Pid == pid) {
+		PROCneedscan = TRUE;
+		pp->Status = status;
 		pp->State = PSdead;
-		pp->Collected = Now.tv_sec;
+		pp->Collected = Now.time;
 		break;
 	    }
     }
 }
 
 
-#ifdef HAVE_SIGACTION
-#define NO_SIGACTION_UNUSED UNUSED
-#else
-#define NO_SIGACTION_UNUSED
-#endif
-
 /*
 **  Signal handler that collects the processes, then resets the signal.
 */
-static void
-PROCcatchsignal(int s NO_SIGACTION_UNUSED)
+STATIC SIGHANDLER
+PROCcatchsignal(s)
+    int			s;
 {
     PROCreap();
-
 #ifndef HAVE_SIGACTION
     xsignal(s, PROCcatchsignal);
 #endif
@@ -71,10 +65,10 @@ PROCcatchsignal(int s NO_SIGACTION_UNUSED)
 **  Synchronous version that notifies a site when its process went away.
 */
 void
-PROCscan(void)
+PROCscan()
 {
-    PROCESS	*pp;
-    int	i;
+    register PROCESS	*pp;
+    register int	i;
 
     for (pp = PROCtable, i = PROCtablesize; --i >= 0; pp++)
 	if (pp->State == PSdead) {
@@ -82,7 +76,7 @@ PROCscan(void)
 		SITEprocdied(&Sites[pp->Site], pp - PROCtable, pp);
 	    pp->State = PSfree;
 	}
-    PROCneedscan = false;
+    PROCneedscan = FALSE;
 }
 
 
@@ -92,11 +86,11 @@ PROCscan(void)
 */
 void
 PROCclose(Quickly)
-    bool		Quickly;
+    BOOL		Quickly;
 {
-    int	sig;
-    PROCESS	*pp;
-    int	i;
+    register int	sig;
+    register PROCESS	*pp;
+    register int	i;
 
     /* What signal are we sending? */
     sig = Quickly ? SIGKILL : SIGTERM;
@@ -123,7 +117,8 @@ PROCclose(Quickly)
 **  Stop watching a process -- we don't care about it any more.
 */
 void
-PROCunwatch(int process)
+PROCunwatch(process)
+    int		process;
 {
     if (process < 0 || process >= PROCtablesize) {
 	syslog(L_ERROR, "%s internal PROCunwatch %d", LogName, process);
@@ -137,10 +132,12 @@ PROCunwatch(int process)
 **  Add a pid to the list of processes we watch.
 */
 int
-PROCwatch(pid_t pid, int site)
+PROCwatch(pid, site)
+    PID_T		pid;
+    int			site;
 {
-    PROCESS     *pp;
-    int         i;
+    register PROCESS	*pp;
+    register int	i;
 
     /* Find a free slot for this process. */
     for (pp = PROCtable, i = PROCtablesize; --i >= 0; pp++)
@@ -148,7 +145,7 @@ PROCwatch(pid_t pid, int site)
 	    break;
     if (i < 0) {
 	/* Ran out of room -- grow the table. */
-        PROCtable = xrealloc(PROCtable, (PROCtablesize + 20) * sizeof(PROCESS));
+	RENEW(PROCtable, PROCESS, PROCtablesize + 20);
         for (pp = &PROCtable[PROCtablesize], i=20; --i >= 0; pp++)
           *pp = PROCnull;
 	pp = &PROCtable[PROCtablesize];
@@ -157,7 +154,7 @@ PROCwatch(pid_t pid, int site)
 
     pp->State = PSrunning;
     pp->Pid = pid;
-    pp->Started = Now.tv_sec;
+    pp->Started = Now.time;
     pp->Site = site;
     return pp - PROCtable;
 }
@@ -167,19 +164,20 @@ PROCwatch(pid_t pid, int site)
 **  Setup.
 */
 void
-PROCsetup(int i)
+PROCsetup(i)
+    register int	i;
 {
-    PROCESS	*pp;
+    register PROCESS	*pp;
 
     if (PROCtable)
-	free(PROCtable);
+	DISPOSE(PROCtable);
     PROCtablesize = i;
-    PROCtable = xmalloc(PROCtablesize * sizeof(PROCESS));
+    PROCtable = NEW(PROCESS, PROCtablesize);
     for (pp = PROCtable, i = PROCtablesize; --i >= 0; pp++)
 	*pp = PROCnull;
 
 #if	defined(SIGCHLD)
-    xsignal(SIGCHLD, PROCcatchsignal);
+    (void)xsignal(SIGCHLD, PROCcatchsignal);
 #endif	/* defined(SIGCHLD) */
-    xsignal(SIGPIPE, PROCcatchsignal);
+    (void)xsignal(SIGPIPE, PROCcatchsignal);
 }
