@@ -1,40 +1,72 @@
-/*  $Id: article.c 10009 2016-05-05 12:39:19Z iulius $
-**
-**  The Article class for innfeed.
-**
-**  Written by James Brister <brister@vix.com>
-**
-**  The implementation of the Article class. Articles are the abstraction for
-**  the actual news articles. They are a reference counted object because they
-**  need to be shared by multiple Host and Connection objects. When an Article
-**  is created it verifies that the actual file exists. When a Connection
-**  wants the article's contents for transmission the Article reads the data
-**  off disk and returns a set of Buffer objects. The Article holds onto these
-**  Buffers so that the next Connection that wants to transmit it won't have
-**  to wait for a disk read to be done again.
-*/
+/* -*- c -*-
+ *
+ * Author:      James Brister <brister@vix.com> -- berkeley-unix --
+ * Start Date:  Wed Dec 27 18:45:55 1995
+ * Project:     INN (innfeed)
+ * File:        article.c
+ * RCSId:       $Id: article.c,v 1.19 1999/11/20 21:22:03 rra Exp $
+ * Copyright:   Copyright (c) 1996 by Internet Software Consortium
+ *
+ *              Permission to use, copy, modify, and distribute this
+ *              software for any purpose with or without fee is hereby
+ *              granted, provided that the above copyright notice and this
+ *              permission notice appear in all copies.
+ *
+ *              THE SOFTWARE IS PROVIDED "AS IS" AND INTERNET SOFTWARE
+ *              CONSORTIUM DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS
+ *              SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
+ *              MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL INTERNET
+ *              SOFTWARE CONSORTIUM BE LIABLE FOR ANY SPECIAL, DIRECT,
+ *              INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
+ *              WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
+ *              WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
+ *              TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE
+ *              USE OR PERFORMANCE OF THIS SOFTWARE.
+ * Description: The implementation of the Article class. Articles are the
+ *              abstraction for the actual news articles. They are a
+ *              reference counted object because they need to be shared by
+ *              multiple Host and Connection objects. When an Article is
+ *              created it verifies that the actual file exists. When a
+ *              Connection wants the article's contents for transmission
+ *              the Article reads the data off disk and returns a set of
+ *              Buffer objects. The Article holds onto these Buffers so
+ *              that the next Connection that wants to transmit it won't
+ *              have to wait for a disk read to be done again.
+ *              
+ * 
+ */
+
+#if ! defined (lint)
+static const char *rcsid = "$Id: article.c,v 1.19 1999/11/20 21:22:03 rra Exp $" ;
+static void use_rcsid (const char *rid) {   /* Never called */
+  use_rcsid (rcsid) ; use_rcsid (rid) ;
+}
+#endif
 
 #include "innfeed.h"
 #include "config.h"
 #include "clibrary.h"
-#include "portable/mmap.h"
 
 #include <assert.h>
-#include <errno.h>
-#include <fcntl.h>
-#if HAVE_LIMITS_H
-# include <limits.h>
-#endif
+#include <sys/mman.h>
 #include <sys/stat.h>
 #include <syslog.h>
 
-#include "inn/messages.h"
-#include "inn/libinn.h"
-#include "inn/storage.h"
+#ifdef HAVE_FCNTL_H
+# include <fcntl.h>
+#endif
+
+#ifdef HAVE_LIMITS_H
+# include <limits.h>
+#endif
+
+#include "libinn.h"
+#include "storage.h"
 
 #include "article.h"
 #include "buffer.h"
 #include "endpoint.h"
+#include "msgs.h"
 
 #if defined (NDEBUG)
 #define VALIDATE_HASH_TABLE() (void (0))
@@ -44,16 +76,6 @@
 
 extern bool useMMap ;
 
-struct map_info_s {
-    ARTHANDLE *arthandle;
-    const void *mMapping;
-    size_t size;
-    int refCount;
-    struct map_info_s *next;
-};
-
-typedef struct map_info_s *MapInfo;
-
 struct article_s 
 {
     int refCount ;              /* the reference count on this article */
@@ -61,10 +83,11 @@ struct article_s
     char *msgid ;               /* the msgid of the article (INN tells us) */
     Buffer contents ;           /* the buffer of the actual on disk stuff */
     Buffer *nntpBuffers ;       /* list of buffers for transmisson */
-    MapInfo mapInfo;		/* arthandle and mMapping */
+    caddr_t mMapping ;          /* base of memory mapping, or NULL if none */
     bool loggedMissing ;        /* true if article is missing and we logged */
     bool articleOk ;            /* true until we know otherwise. */
     bool inWireFormat ;         /* true if ->contents is \r\n/dot-escaped */
+    ARTHANDLE *arthandle ;      /* Storage manager article handle */
 } ;
 
 struct hash_entry_s {
@@ -72,7 +95,7 @@ struct hash_entry_s {
     struct hash_entry_s *prev ;
     struct hash_entry_s *nextTime ;
     struct hash_entry_s *prevTime ;
-    unsigned int hash ;
+    u_int hash ;
     Article article ;
 };
 
@@ -102,8 +125,7 @@ static bool artFreeContents (Article art) ;  /* Tell the Article to release
                                                 its contents buffer if
                                                 possible. */
 
-static void artUnmap (Article art) ; /* munmap an mmap()ed
-                                                     article */
+static void artUnmap (Article art, int size) ; /* munmap an mmap()ed article */
 
 
   /*
@@ -111,7 +133,7 @@ static void artUnmap (Article art) ; /* munmap an mmap()ed
    */
 
   /* Returns a has value for the given string */
-static unsigned int hashString (const char *string) ;
+static u_int hashString (const char *string) ;
 
   /* Locates the article with the given message ID, in the has table. */
 static Article hashFindArticle (const char *msgid) ;
@@ -132,40 +154,40 @@ static void hashValidateTable (void) ;
    */
 
 
-static unsigned int missingArticleCount ;  /* Number of articles that were missing */
+static u_int missingArticleCount ;  /* Number of articles that were missing */
 
 static bool logMissingArticles ;  /* if true then we log the details on a
                                      missing article. */ 
 
-static unsigned int preparedBytes ;  /* The number of areticle bytes read in so
+static u_int preparedBytes ;  /* The number of areticle bytes read in so
                                  far of disk (will wrap around) */
 
-static unsigned int preparedNewlines ; /* The number of newlines found in all the
+static u_int preparedNewlines ; /* The number of newlines found in all the
                                    preparedBytes */
 
-static unsigned int avgCharsPerLine ;  /* The average number of characters per
+static u_int avgCharsPerLine ;  /* The average number of characters per
                                    line over all articles. */
 
 static bool rolledOver ;  /* true if preparedBytes wrapped around */
 
-static unsigned int bytesInUse ;   /* count of article contents bytes in use--just
+static u_int bytesInUse ;   /* count of article contents bytes in use--just
                                the amount read from the article files, not
                                all memory involved in. */
 
-static unsigned int maxBytesInUse ;   /* the limit we want to stay under for total
+static u_int maxBytesInUse ;   /* the limit we want to stay under for total
                                   bytes resident in memory dedicated to
                                   article contents. */
 
-static unsigned int articlesInUse ;  /* number of articles currently allocated. */
+static u_int articlesInUse ;  /* number of articles currently allocated. */
 
-static unsigned int byteTotal ;        /* number of bytes for article contents
+static u_int byteTotal ;        /* number of bytes for article contents
                                    allocated totally since last log. */
 
-static unsigned int articleTotal ; /* number of articles alloced since last log. */
+static u_int articleTotal ; /* number of articles alloced since last log. */
 
 static TimeoutId articleStatsId ; /* The timer callback id. */
 
-static MapInfo mapInfo;
+
 
   /*
    * Hash Table data
@@ -191,13 +213,13 @@ Article newArticle (const char *filename, const char *msgid)
 {
   Article newArt = NULL ;
   
-  TMRstart(TMR_NEWARTICLE);
   if (hashTable == NULL)
     {                           /* first-time through initialization. */
       int i ;
       
       ASSERT ((TABLE_SIZE & HASH_MASK) == 0) ;
-      hashTable = xmalloc (sizeof(HashEntry) * TABLE_SIZE) ;
+      hashTable = ALLOC (HashEntry, TABLE_SIZE) ;
+      ASSERT (hashTable != NULL) ;
       
       addPointerFreedOnExit ((char *)hashTable) ;
 
@@ -212,19 +234,26 @@ Article newArticle (const char *filename, const char *msgid)
        ok */
   if ((newArt = hashFindArticle (msgid)) == NULL)
     {
-      newArt = xcalloc (1, sizeof(struct article_s)) ;
-
-      newArt->fname = xstrdup (filename) ;
-      newArt->msgid = xstrdup (msgid) ;
+      newArt = CALLOC (struct article_s, 1) ;
+      ASSERT (newArt != NULL) ;
+      
+      newArt->fname = MALLOC (strlen (filename) + 1) ;
+      ASSERT (newArt->fname != NULL) ;
+      strcpy (newArt->fname,filename) ;
+      
+      newArt->msgid = MALLOC (strlen (msgid) + 1) ;
+      ASSERT (newArt->msgid != NULL) ;
+      strcpy (newArt->msgid,msgid) ;
       
       newArt->contents = NULL ;
-      newArt->mapInfo = NULL ;
+      newArt->mMapping = NULL ;
       newArt->refCount = 1 ;
       newArt->loggedMissing = false ;
       newArt->articleOk = true ;
       newArt->inWireFormat = false ;
+      newArt->arthandle = NULL;
       
-      d_printf (3,"Adding a new article(%p): %s\n", (void *)newArt, msgid) ;
+      d_printf (3,"Adding a new article(%p): %s\n", newArt, msgid) ;
       
       articlesInUse++ ;
       articleTotal++ ;
@@ -234,13 +263,12 @@ Article newArticle (const char *filename, const char *msgid)
   else
     {
       if (strcmp (filename,newArt->fname) != 0)
-        warn ("ME two filenames for same article: %s, %s", filename,
-              newArt->fname) ;
+        syslog (LOG_ERR, DOUBLE_NAME, filename, newArt->fname) ;
       
       newArt->refCount++ ;
-      d_printf (2,"Reusing existing article for %s\n",msgid) ;
+      d_printf (2,"Reusing existing article for %s\nx",msgid) ;
     }
-  TMRstop(TMR_NEWARTICLE);
+  
   return newArt ;
 }
 
@@ -260,13 +288,12 @@ void delArticle (Article article)
 
       ASSERT (removed == true) ;
 
-      d_printf (2,"Cleaning up article (%p): %s\n", 
-          (void *)article, article->msgid) ;
+      d_printf (2,"Cleaning up article (%p): %s\n",article, article->msgid) ;
 
       if (article->contents != NULL)
         {
-          if (article->mapInfo)
-            artUnmap(article);
+          if (article->mMapping)
+            artUnmap(article, bufferSize(article->contents)) ;
           else
             bytesInUse -= bufferDataSize (article->contents) ;
       
@@ -277,39 +304,39 @@ void delArticle (Article article)
         }
 
       articlesInUse-- ;
-
-      free (article->fname) ;
-      free (article->msgid) ;
-      free (article) ;
+      
+      FREE (article->fname) ;
+      FREE (article->msgid) ;
+      FREE (article) ;
     }
 
   VALIDATE_HASH_TABLE () ;
 }
 
 
-void gPrintArticleInfo (FILE *fp, unsigned int indentAmt)
+void gPrintArticleInfo (FILE *fp, u_int indentAmt)
 {
   char indent [INDENT_BUFFER_SIZE] ;
-  unsigned int i ;
+  u_int i ;
 
   for (i = 0 ; i < MIN(INDENT_BUFFER_SIZE - 1,indentAmt) ; i++)
     indent [i] = ' ' ;
   indent [i] = '\0' ;
 
-  fprintf (fp,"%sGlobal Article information : (count %u) {\n",
+  fprintf (fp,"%sGlobal Article information : (count %d) {\n",
            indent, articlesInUse) ;
 
-  fprintf (fp,"%s  missingArticleCount : %u\n",indent,missingArticleCount) ;
+  fprintf (fp,"%s  missingArticleCount : %d\n",indent,missingArticleCount) ;
   fprintf (fp,"%s  logMissingArticles : %d\n",indent,logMissingArticles) ;
-  fprintf (fp,"%s  preparedBytes : %u\n",indent,preparedBytes) ;
-  fprintf (fp,"%s  preparedNewlines : %u\n",indent,preparedNewlines) ;
-  fprintf (fp,"%s  avgCharsPerLine : %u\n",indent,avgCharsPerLine) ;
+  fprintf (fp,"%s  preparedBytes : %d\n",indent,preparedBytes) ;
+  fprintf (fp,"%s  preparedNewlines : %d\n",indent,preparedNewlines) ;
+  fprintf (fp,"%s  avgCharsPerLine : %d\n",indent,avgCharsPerLine) ;
   fprintf (fp,"%s  rolledOver : %s\n",indent,boolToString (rolledOver)) ;
-  fprintf (fp,"%s  bytesInUse : %u\n",indent,bytesInUse) ;
-  fprintf (fp,"%s  maxBytesInUse : %u\n",indent,maxBytesInUse) ;
-  fprintf (fp,"%s  articlesInUse : %u\n",indent,articlesInUse) ;
-  fprintf (fp,"%s  byteTotal : %u\n",indent,byteTotal) ;
-  fprintf (fp,"%s  articleTotal : %u\n",indent,articleTotal) ;
+  fprintf (fp,"%s  bytesInUse : %d\n",indent,bytesInUse) ;
+  fprintf (fp,"%s  maxBytesInUse : %d\n",indent,maxBytesInUse) ;
+  fprintf (fp,"%s  articlesInUse : %d\n",indent,articlesInUse) ;
+  fprintf (fp,"%s  byteTotal : %d\n",indent,byteTotal) ;
+  fprintf (fp,"%s  articleTotal : %d\n",indent,articleTotal) ;
   fprintf (fp,"%s  articleStatsId : %d\n",indent,articleStatsId) ;
   
   {
@@ -323,17 +350,17 @@ void gPrintArticleInfo (FILE *fp, unsigned int indentAmt)
 }
 
 
-void printArticleInfo (Article art, FILE *fp, unsigned int indentAmt)
+void printArticleInfo (Article art, FILE *fp, u_int indentAmt)
 {
   Buffer *b ;
   char indent [INDENT_BUFFER_SIZE] ;
-  unsigned int i ;
+  u_int i ;
 
   for (i = 0 ; i < MIN(INDENT_BUFFER_SIZE - 1,indentAmt) ; i++)
     indent [i] = ' ' ;
   indent [i] = '\0' ;
   
-  fprintf (fp,"%sArticle : %p {\n",indent,(void *) art) ;
+  fprintf (fp,"%sArticle : %p {\n",indent,art) ;
   fprintf (fp,"%s    article ok : %s\n",indent,boolToString (art->articleOk)) ;
   fprintf (fp,"%s    refcount : %d\n",indent,art->refCount) ;
   fprintf (fp,"%s    filename : %s\n",indent,art->fname) ;
@@ -423,7 +450,7 @@ int artSize (Article article)
 
 
   /* return how many NNTP-ready buffers the article contains */
-unsigned int artNntpBufferCount (Article article)
+u_int artNntpBufferCount (Article article)
 {
   if ( !prepareArticleForNNTP (article) )
     return 0 ;
@@ -440,7 +467,7 @@ void artLogMissingArticles (bool val)
 
 
   /* set the limit we want to stay under. */
-void artSetMaxBytesInUse (unsigned int val)
+void artSetMaxBytesInUse (u_int val)
 {
   ASSERT (maxBytesInUse > 0) ;  /* can only set one time. */
   ASSERT (val > 0) ;
@@ -472,77 +499,29 @@ static Buffer artGetContents (Article article)
   return rval ;
 }
 
-  /* arthandle/mMapping needs to be refcounted since a buffer
-     may exist referencing it after delArticle if the remote
-     host sends the return status too soon (diablo, 439). */
 
-static MapInfo getMapInfo(ARTHANDLE *arthandle,
-		const void *mMapping, size_t size)
-{
-  MapInfo m;
-
-  for (m = mapInfo; m; m = m->next) {
-    if (m->arthandle == arthandle &&
-        m->mMapping == mMapping) {
-      m->refCount++;
-      return m;
-    }
-  }
-
-  m = xmalloc(sizeof(struct map_info_s));
-  m->refCount = 1;
-  m->arthandle = arthandle;
-  m->mMapping = mMapping;
-  m->size = size;
-  m->next = mapInfo;
-  mapInfo = m;
-
-  return m;
-}
-
-static void delMapInfo(void *vm)
-{
-    MapInfo i, prev;
-    MapInfo m = (MapInfo)vm;
-
-    if (m == NULL)
-      return;
-
-    if (--(m->refCount) > 0)
-      return;
-
-    if (m->arthandle)
-      SMfreearticle(m->arthandle);
+static void artUnmap (Article article, int size) {
+    
+    if (article->arthandle)
+	SMfreearticle(article->arthandle);
     else
-      if (munmap(m->mMapping, m->size) < 0)
-	syslog (LOG_NOTICE, "munmap article: %m");
+	if (munmap(article->mMapping, size) < 0)
+	    syslog (LOG_NOTICE, "munmap %s: %m", article->fname) ;
 
-    prev = NULL;
-    for (i = mapInfo; i != m; i = i->next)
-      prev = i;
-
-    if (prev)
-      prev->next = m->next;
-    else
-      mapInfo = m->next;
-
-    free(m);
-}
-
-static void artUnmap (Article article) {
-
-    delMapInfo(article->mapInfo);
-    article->mapInfo = NULL;
+    article->arthandle = NULL;
+    article->mMapping = NULL ;
 }
 
 
 
-static void logArticleStats (TimeoutId id, void *data UNUSED)
+static void logArticleStats (TimeoutId id, void *data)
 {
   ASSERT (id == articleStatsId) ;
 
-  notice ("ME articles active %d bytes %d", articlesInUse, bytesInUse) ;
-  notice ("ME articles total %d bytes %d", articleTotal, byteTotal) ;
+  (void) data ;                 /* keep lint happy */
+
+  syslog (LOG_NOTICE,ACTIVE_ARTICLES,articlesInUse,bytesInUse) ;
+  syslog (LOG_NOTICE,ARTICLE_ALLOCS,articleTotal,byteTotal) ;
   
   byteTotal = 0 ;
   articleTotal = 0 ;
@@ -561,22 +540,19 @@ static void logArticleStats (TimeoutId id, void *data UNUSED)
 
 static bool fillContents (Article article)
 {
-    int fd = -1;
+    int fd ;
     char *p;
     static bool maxLimitNotified ;
     bool opened;
-    size_t articlesize = 0;
+    int articlesize;
     char *buffer = NULL ;
     int amt = 0 ;
     size_t idx = 0, amtToRead ;
     size_t newBufferSize ;
     HashEntry h ;
-    ARTHANDLE *arthandle = NULL;
-    const void *mMapping = NULL;
-
+  
     ASSERT (article->contents == NULL) ;
     
-    TMRstart(TMR_READART);
     if (maxBytesInUse == 0)
 	maxBytesInUse = SOFT_ARTICLE_BYTE_LIMIT ;
     
@@ -584,15 +560,14 @@ static bool fillContents (Article article)
 	avgCharsPerLine = 75 ;      /* roughly number of characters per line */
     
     if (IsToken(article->fname)) {
-	opened = ((arthandle = SMretrieve(TextToToken(article->fname), RETR_ALL)) != NULL) ? true : false;
+	opened = ((article->arthandle = SMretrieve(TextToToken(article->fname), RETR_ALL)) != NULL) ? true : false;
 	if (opened)
-	    articlesize = arthandle->len;
+	    articlesize = article->arthandle->len;
 	else {
 	    if (SMerrno != SMERR_NOENT && SMerrno != SMERR_UNINIT) {
 		syslog(LOG_ERR, "Could not retrieve %s: %s",
 		       article->fname, SMerrorstr);
 		article->articleOk = false;
-		TMRstop(TMR_READART); 
 		return false;
 	    }
 	}
@@ -600,24 +575,21 @@ static bool fillContents (Article article)
 	struct stat sb ;
 	
 	opened = ((fd = open (article->fname,O_RDONLY,0)) >= 0) ? true : false;
-	arthandle = NULL;
+	article->arthandle = NULL;
 	if (opened) {
 	    if (fstat (fd, &sb) < 0) {
 		article->articleOk = false ;
-                syswarn ("ME oserr fstat %s", article->fname) ;
-		TMRstop(TMR_READART);
+		syslog (LOG_ERR,FSTAT_FAILURE,article->fname) ;
 		return false;
 	    }
 	    if (!S_ISREG (sb.st_mode)) {
 		article->articleOk = false ;
-                warn ("ME article file-type: %s", article->fname) ;
-		TMRstop(TMR_READART);
+		syslog (LOG_ERR,REGFILE_FAILURE,article->fname) ;
 		return false;
 	    }
 	    if (sb.st_size == 0) {
 		article->articleOk = false ;
-                warn ("ME article 0 bytes: %s", article->fname) ;
-		TMRstop(TMR_READART);
+		syslog (LOG_ERR,EMPTY_ARTICLE,article->fname) ;
 		return false;
 	    }
 	    articlesize = sb.st_size;
@@ -630,45 +602,37 @@ static bool fillContents (Article article)
 	
 	if (logMissingArticles && !article->loggedMissing)
 	{
-            notice ("ME article missing: %s, %s", article->msgid,
-                    article->fname) ;
+	    syslog (LOG_NOTICE,NO_ARTICLE,article->msgid,article->fname) ;
 	    article->loggedMissing = true ;
 	}
-	TMRstop(TMR_READART);
 	return false;
     }
-    amtToRead = articlesize ;
-    newBufferSize = articlesize ;
+    amtToRead = (size_t) articlesize ;
+    newBufferSize = (size_t) articlesize ;
     
-    if (arthandle || useMMap) {
-	if (arthandle)
-	    mMapping = arthandle->data;
+    if (article->arthandle || useMMap) {
+	if (article->arthandle)
+	    article->mMapping = article->arthandle->data;
 	else 
-	    mMapping = mmap(NULL, articlesize, PROT_READ,
-                                     MAP_SHARED, fd, 0);
+	    article->mMapping = mmap((caddr_t) 0, (size_t) articlesize,
+				     PROT_READ, MAP_SHARED, fd, 0);
 	
-	if (mMapping == MAP_FAILED) {
+	if (article->mMapping == (caddr_t) -1) {
 	    /* dunno, but revert to plain reading */
-	    mMapping = NULL ;
-            syswarn ("ME mmap failure %s (%s)",
-                     article->fname,
-                     strerror(errno)) ;
+	    article->mMapping = NULL ;
+	    syslog (LOG_NOTICE, MMAP_FAILURE, article->fname) ;
 	} else {
-	    article->contents = newBufferByCharP(mMapping,
-						 articlesize,
-						 articlesize);
-	    article->mapInfo = getMapInfo(arthandle, mMapping, articlesize);
-	    article->mapInfo->refCount++; /* one more for the buffer */
-	    bufferSetDeletedCbk(article->contents, delMapInfo, article->mapInfo);
-
+	    article->contents = newBufferByCharP((char *)article->mMapping,
+						 (size_t) articlesize,
+						 (size_t) articlesize);
 	    buffer = bufferBase (article->contents) ;
 	    if ((p = strchr(buffer, '\n')) == NULL) {
 		article->articleOk = false;
 		delBuffer (article->contents) ;
 		article->contents = NULL ;
-                warn ("ME munged article %s", article->fname) ;
+		syslog (LOG_NOTICE, MUNGED_ARTICLE, article->fname) ;
 	    } else {
-                if (p > buffer && p[-1] == '\r') {
+		if (p[-1] == '\r') {
 		    article->inWireFormat = true ;
 		} else {
 		    /* we need to copy the contents into a buffer below */
@@ -699,9 +663,8 @@ static bool fillContents (Article article)
 	/* we we couldn't get below, then log it (one time only) */
 	if ((amtToRead + bytesInUse) > maxBytesInUse && maxLimitNotified == false) {
 	    maxLimitNotified = true ;
-            notice ("ME exceeding maximum article byte limit: %d (max),"
-                    " %lu (cur)", maxBytesInUse, 
-                    (unsigned long) (amtToRead + bytesInUse)) ;
+	    syslog (LOG_NOTICE,MAX_BYTES_LIMIT,maxBytesInUse,
+		    amtToRead + bytesInUse) ;
 	}
 	
 	if ((article->contents = newBuffer (newBufferSize)) == NULL)
@@ -712,15 +675,16 @@ static bool fillContents (Article article)
 	    byteTotal += articlesize ;
 	}
 	
-	if (mMapping && buffer != NULL) {               
-	    memcpy(buffer, mMapping, articlesize);
-	    artUnmap(article) ;
+	if (article->mMapping && buffer != NULL) {               
+	    (void)memcpy(buffer, (char *) article->mMapping,
+			 (int) articlesize);
+	    artUnmap(article, (int) articlesize) ;
 	    amtToRead = 0;
 	}
 	
 	while (amtToRead > 0) {
 	    if ((amt = read (fd, buffer + idx,amtToRead)) <= 0) {
-                syswarn ("ME article read error: %s", article->fname) ;
+		syslog (LOG_ERR,BAD_ART_READ, article->fname) ;
 		bytesInUse -= articlesize ;
 		byteTotal -= articlesize ;
 		amtToRead = 0 ;
@@ -735,22 +699,24 @@ static bool fillContents (Article article)
 	}
 	
 	if (article->contents != NULL) {
-	    bufferSetDataSize (article->contents, articlesize) ;
+	    bufferSetDataSize (article->contents, (size_t) articlesize) ;
 	    
 	    if ((p = strchr(buffer, '\n')) == NULL) {                  
 		article->articleOk = false;
-                warn ("ME munged article %s", article->fname) ;
-            } else if (p > buffer && p[-1] == '\r') {
-                article->inWireFormat = true ;
-            } else {
+		syslog (LOG_NOTICE, MUNGED_ARTICLE, article->fname) ;
+	    }
+	    else if (p[-1] == '\r') {
+		article->inWireFormat = true ;
+	    }
+	    else {
 		if ( nntpPrepareBuffer (article->contents) ) {
 		    size_t diff =
 			(bufferDataSize (article->contents) - articlesize) ;
 		    
-		    if (((unsigned int) UINT_MAX) - diff <= preparedBytes) {
+		    if (((u_int) UINT_MAX) - diff <= preparedBytes) {
 			d_printf (2,"Newline ratio so far: %02.2f\n",
 				 ((double) preparedBytes / preparedNewlines)) ;
-                        notice ("ME newline to file size ratio: %0.2f (%d/%d)",
+			syslog (LOG_NOTICE,PREPARED_NEWLINES,
 				((double) preparedBytes)/preparedNewlines,
 				preparedBytes,preparedNewlines) ;
 			preparedBytes = 0 ;
@@ -770,7 +736,7 @@ static bool fillContents (Article article)
 		    }
 		    article->inWireFormat = true ;
 		} else {
-                    warn ("ME internal failed to prepare buffer for NNTP") ;
+		    syslog (LOG_ERR,PREPARE_FAILED) ;
 		    bytesInUse -= articlesize ;
 		    byteTotal -= articlesize ;
 		    
@@ -783,10 +749,9 @@ static bool fillContents (Article article)
 
     
     /* If we're not useing storage api, we should close a valid file descriptor */
-    if (!arthandle && (fd >= 0))
+    if (!article->arthandle && (fd >= 0))
 	close (fd) ;
-
-    TMRstop(TMR_READART);
+  
     return (article->contents != NULL ? true : false) ;
 }
 
@@ -801,7 +766,8 @@ static void appendBuffer (Buffer b, Buffer **buffs, int *newSpot, int *curLen)
   if (*newSpot == *curLen)
     {
       *curLen += 10 ;
-      *buffs = xrealloc (*buffs, sizeof(Buffer) * *curLen) ;
+      *buffs = REALLOC (*buffs, Buffer, *curLen) ;
+      ASSERT (*buffs != NULL) ;
     }
   (*buffs) [(*newSpot)++] = b ;
 }
@@ -813,30 +779,28 @@ static void appendBuffer (Buffer b, Buffer **buffs, int *newSpot, int *curLen)
      characters as needed */
 static bool prepareArticleForNNTP (Article article)
 {
+  static Buffer dotFirstBuffer ;
   static Buffer dotBuffer ;
+  static Buffer crlfBuffer ;
   Buffer *nntpBuffs = NULL ;
   int buffLen = 0 ;
   int buffIdx = 0 ;
   char *start, *end ;
-  Buffer contents ;
+  Buffer contents = artGetContents (article) ; /* returns a reference */
 
-  contents = artGetContents (article) ; /* returns a reference */
-
-  TMRstart(TMR_PREPART);
-  if (contents == NULL) {
-    TMRstop(TMR_PREPART);
+  if (contents == NULL)
     return false ;
-  }
   else if (article->nntpBuffers != NULL)
     {
       delBuffer (contents) ;
-      TMRstop(TMR_PREPART);
       return true ;               /* already done */
     }
 
   if (dotBuffer == NULL)
     {
       dotBuffer = newBufferByCharP (".\r\n",3,3) ;
+      dotFirstBuffer = newBufferByCharP ("\r\n.",3,3) ;
+      crlfBuffer = newBufferByCharP ("\r\n",2,2) ;
     }
 
   /* overlay a set of buffers on top of the articles contents buffer. This
@@ -867,22 +831,19 @@ static bool prepareArticleForNNTP (Article article)
     }
   else
     {
-      /* we already fixed the contents up when we read in the article */
-      nntpBuffs = xmalloc (sizeof(Buffer) * 3) ;
+        /* we already fixed the contents up when we read in the article */
+      nntpBuffs = ALLOC (Buffer, 3) ;
+      ASSERT (nntpBuffs != NULL) ;
       nntpBuffs [0] = newBufferByCharP (bufferBase (contents),
                                         bufferDataSize (contents),
                                         bufferDataSize (contents)) ;
-      if (article->mapInfo) {
-	article->mapInfo->refCount++;
-	bufferSetDeletedCbk(nntpBuffs[0], delMapInfo, article->mapInfo);
-      }
       nntpBuffs [1] = NULL ;
     }
   
       
   delBuffer (contents) ;    /* the article is still holding a reference */
   article->nntpBuffers = nntpBuffs ;
-  TMRstop(TMR_PREPART);
+
   return true ;
 }
 
@@ -895,7 +856,6 @@ static bool artFreeContents (Article art)
     return false ;
 
   if (art->nntpBuffers != NULL)
-    {
     if (bufferRefCount (art->nntpBuffers[0]) > 1)
       return false ;
     else
@@ -903,12 +863,11 @@ static bool artFreeContents (Article art)
         freeBufferArray (art->nntpBuffers) ;    
         art->nntpBuffers = NULL ;
       }
-    }
 
   ASSERT (bufferRefCount (art->contents) == 1) ;
 
-  if (art->mapInfo)
-    artUnmap(art);
+  if (art->mMapping)
+    artUnmap(art, bufferSize(art->contents)) ;
   else
     bytesInUse -= bufferDataSize (art->contents) ;
   
@@ -934,9 +893,9 @@ static bool artFreeContents (Article art)
 
 
   /* Hash function lifted from perl 5 */
-static unsigned int hashString (const char *string)
+static u_int hashString (const char *string)
 {
-  unsigned int i ;
+  u_int i ;
 
   for (i = 0 ; string && *string ; string++)
     i = 33 * i + (u_char) *string ;
@@ -948,7 +907,7 @@ static unsigned int hashString (const char *string)
   /* find the article in the has table and return it. */
 static Article hashFindArticle (const char *msgid)
 {
-  unsigned int hash = hashString (msgid) ;
+  u_int hash = hashString (msgid) ;
   HashEntry h ;
 
   for (h = hashTable [TABLE_ENTRY(hash)] ; h != NULL ; h = h->next)
@@ -962,13 +921,14 @@ static Article hashFindArticle (const char *msgid)
   /* add the article to the hash table. */
 static void hashAddArticle (Article article)
 {
-  unsigned int hash = hashString (article->msgid) ;
+  u_int hash = hashString (article->msgid) ;
   HashEntry h ;
   HashEntry ne ;
 
   h = hashTable [TABLE_ENTRY(hash)] ;
 
-  ne = xmalloc (sizeof(struct hash_entry_s));
+  ne = ALLOC (struct hash_entry_s, 1) ;
+  ASSERT (ne != NULL) ;
 
   ne->article = article ;
   ne->hash = hash ;
@@ -994,7 +954,7 @@ static void hashAddArticle (Article article)
      Does not delete the article itself. */
 static bool hashRemoveArticle (Article article)
 {
-  unsigned int hash = hashString (article->msgid) ;
+  u_int hash = hashString (article->msgid) ;
   HashEntry h ;
 
   for (h = hashTable [TABLE_ENTRY(hash)] ; h != NULL ; h = h->next)
@@ -1029,8 +989,8 @@ static bool hashRemoveArticle (Article article)
       if (h->nextTime != NULL)
         h->nextTime->prevTime = h->prevTime ;
     }
-
-  free (h) ;
+  
+  FREE (h) ;
   
   return true ;
 }
