@@ -4,7 +4,7 @@
  * Start Date:  Wed Dec 27 17:10:18 1995
  * Project:     INN (innfeed)
  * File:        misc.c
- * RCSId:       $Id: misc.c,v 1.8.2.4 2001/04/12 16:20:24 rra Exp $
+ * RCSId:       $Id: misc.c,v 1.8.2.5 2001/06/19 22:54:28 kondou Exp $
  *
  * Copyright:   Copyright (c) 1996 by Internet Software Consortium
  *
@@ -29,7 +29,7 @@
  */
 
 #if ! defined (lint)
-static const char *rcsid = "$Id: misc.c,v 1.8.2.4 2001/04/12 16:20:24 rra Exp $" ;
+static const char *rcsid = "$Id: misc.c,v 1.8.2.5 2001/06/19 22:54:28 kondou Exp $" ;
 static void use_rcsid (const char *rid) {   /* Never called */
   use_rcsid (rcsid) ; use_rcsid (rid) ;
 }
@@ -154,7 +154,10 @@ void logOrPrint (int level, FILE *fp, const char *fmt, ...)
     }
   else
     {
-      dolog (level,fmt,ap) ;
+      char buffer [512] ;
+
+      vsnprintf (buffer,sizeof (buffer),fmt,ap) ;
+      syslog (level,buffer) ;
     }
   va_end (ap) ;
 }
