@@ -1,15 +1,15 @@
-/*  $Id: defdist.c 6135 2003-01-19 01:15:40Z rra $
+/*  $Revision: 1.5 $
 **
 */
-
-#include "config.h"
+#include <stdio.h>
+#include <sys/types.h>
+#include "configdata.h"
 #include "clibrary.h"
 #include <ctype.h>
 #include <errno.h>
-
-#include "inn/innconf.h"
 #include "libinn.h"
 #include "paths.h"
+#include "macros.h"
 
 
 typedef struct _DDENTRY {
@@ -25,8 +25,7 @@ struct _DDHANDLE {
 };
 typedef struct _DDHANDLE	DDHANDLE;
 
-struct _DDHANDLE *
-DDstart(FILE *FromServer, FILE *ToServer)
+struct _DDHANDLE *DDstart(FILE *FromServer, FILE *ToServer)
 {
     DDHANDLE	*h;
     DDENTRY	*ep;
@@ -34,26 +33,20 @@ DDstart(FILE *FromServer, FILE *ToServer)
     char	buff[BUFSIZ];
     char	*p;
     char	*q;
-    char        *path;
     int		i;
-    int         fd;
-    char	*name = NULL;
+    char	name[256];
 
     /* Open the file. */
-    path = concatpath(innconf->pathetc, _PATH_DISTPATS);
-    F = fopen(path, "r");
-    free(path);
-    if (F == NULL) {
+    if ((F = fopen(cpcatpath(innconf->pathetc, _PATH_DISTPATS), "r")) != NULL) {
+	name[0] = '\0';
+    } else {
 	/* Not available locally; try remotely. */
 	if (FromServer == NULL || ToServer == NULL)
 	    /* We're probably nnrpd running on the server and the
 	     * file isn't installed.  Oh well. */
 	    return NULL;
-        name = concatpath(innconf->pathtmp, _PATH_TEMPACTIVE);
-        fd = mkstemp(name);
-        if (fd < 0)
-            return NULL;
-        close(fd);
+	(void)sprintf(name, "%.220s/%s", innconf->pathtmp, _PATH_TEMPACTIVE);
+	(void)mktemp(name);
 	if ((F = CA_listopen(name, FromServer, ToServer,
 		    "distrib.pats")) == NULL)
 	    return NULL;
@@ -64,11 +57,11 @@ DDstart(FILE *FromServer, FILE *ToServer)
 	continue;
 
     /* Allocate space for the handle. */
-    if ((h = xmalloc(sizeof(DDHANDLE))) == NULL) {
+    if ((h = NEW(DDHANDLE, 1)) == NULL) {
 	i = errno;
-	fclose(F);
-	if (name != NULL)
-	    unlink(name);
+	(void)fclose(F);
+	if (name[0])
+	    (void)unlink(name);
 	errno = i;
 	return NULL;
     }
@@ -76,17 +69,17 @@ DDstart(FILE *FromServer, FILE *ToServer)
     h->Current = NULL;
     if (i == 0) {
         return NULL ;
-    } else if ((h->Entries = xmalloc(sizeof(DDENTRY) * i)) == NULL) {
+    } else if ((h->Entries = NEW(DDENTRY, i)) == NULL) {
 	i = errno;
-	free(h);
-	fclose(F);
-	if (name != NULL)
-	    unlink(name);
+	DISPOSE(h);
+	(void)fclose(F);
+	if (name[0])
+	    (void)unlink(name);
 	errno = i;
 	return NULL;
     }
 
-    fseeko(F, 0, SEEK_SET);
+    (void)fseek(F, (OFFSET_T)0, SEEK_SET);
     for (ep = h->Entries; fgets(buff, sizeof buff, F) != NULL; ) {
 	if ((p = strchr(buff, '\n')) != NULL)
 	    *p = '\0';
@@ -97,7 +90,7 @@ DDstart(FILE *FromServer, FILE *ToServer)
 	    continue;
 	*p++ = '\0';
 	ep->Weight = atoi(buff);
-	ep->Pattern = xstrdup(p);
+	ep->Pattern = COPY(p);
 	q = strchr(ep->Pattern, ':');
 	*q++ = '\0';
 	ep->Value = q;
@@ -105,15 +98,14 @@ DDstart(FILE *FromServer, FILE *ToServer)
     }
     h->Count = ep - h->Entries;
 
-    fclose(F);
-    if (name != NULL)
-	unlink(name);
+    (void)fclose(F);
+    if (name[0])
+	(void)unlink(name);
     return h;
 }
 
 
-void
-DDcheck(DDHANDLE *h, char *group)
+void DDcheck(DDHANDLE *h, char *group)
 {
     DDENTRY	*ep;
     int		i;
@@ -124,15 +116,14 @@ DDcheck(DDHANDLE *h, char *group)
 
     w = h->Current ? h->Current->Weight : -1;
     for (ep = h->Entries, i = h->Count; --i >= 0; ep++)
-	if (ep->Weight > w && uwildmat(group, ep->Pattern)) {
+	if (ep->Weight > w && wildmat(group, ep->Pattern)) {
 	    h->Current = ep;
 	    w = ep->Weight;
 	}
 }
 
 
-char *
-DDend(DDHANDLE *h)
+char *DDend(DDHANDLE *h)
 {
     static char	NIL[] = "";
     char	*p;
@@ -141,25 +132,27 @@ DDend(DDHANDLE *h)
 
     if (h == NULL) {
 	p = NIL;
-	return xstrdup(p);
+	return COPY(p);
     }
 
     if (h->Current == NULL)
 	p = NIL;
     else
 	p = h->Current->Value;
-    p = xstrdup(p);
+    p = COPY(p);
 
     for (ep = h->Entries, i = h->Count; --i >= 0; ep++)
-	free(ep->Pattern);
-    free(h->Entries);
-    free(h);
+	DISPOSE(ep->Pattern);
+    DISPOSE(h->Entries);
+    DISPOSE(h);
     return p;
 }
 
 #if	defined(TEST)
 int
-main(int ac, char *av[])
+main(ac, av)
+    int			ac;
+    char		*av[];
 {
     struct _DDHANDLE	*h;
     char		*p;
@@ -173,7 +166,7 @@ main(int ac, char *av[])
 	if ((p = strchr(buff, '\r')) != NULL)
 	    *p = '\0';
 	if (buff[0])
-	    fprintf(stderr, "%s\n", buff);
+	    (void)fprintf(stderr, "%s\n", buff);
 	else
 	    perror("Can't connect");
 	exit(1);
