@@ -1,4 +1,4 @@
-/*  $Revision: 1.8 $
+/*  $Revision: 1.10 $
 **
 */
 #include <stdio.h>
@@ -53,38 +53,9 @@ const char *HeaderFindMem(const char *Article, const int ArtLen, const char *Hea
 		}
 	    }
 	}
-	if ((p = memchr(p, '\n', ArtLen - (p - Article))) == NULL ||
-	    ++p >= Article + ArtLen || *p == '\n' || (*p == '\r' &&
-	    ++p >= Article + ArtLen || *p == '\n'))
+	if ((p = memchr(p, '\n', ArtLen - (p - Article))) == NULL
+	    || ++p >= Article + ArtLen || *p == '\n'
+	    || (*p == '\r' && (++p >= Article + ArtLen || *p == '\n')))
 	    return NULL;
     }
 }
-
-const char *HeaderFindDisk(const char *file, const char *Header, const int HeaderLen) {
-    QIOSTATE            *qp;
-    char                *line;
-    char                *p;
-
-    if ((qp = QIOopen(file)) == NULL)
-	return NULL;
-
-    while ((line = QIOread(qp)) != NULL) {
-	if (caseEQn(Header, line, HeaderLen)) {
-	    line = COPY(line);
-	    /* append contiguous line */
-	    while ((p = QIOread(qp)) != NULL && ISWHITE(*p)) {
-		RENEW(line, char, strlen(line) + strlen(p) + 1);
-		strcat(line, p);
-	    }
-	    QIOclose(qp);
-	    return line;
-	}
-	if (strlen(line) == 0) {
-	    /* end-of-header */
-	    QIOclose(qp);
-	    return NULL;
-	}
-    }
-    QIOclose(qp);
-    return NULL;
-}
