@@ -1,17 +1,15 @@
-/*  $Id: resource.c 9754 2014-12-01 21:08:28Z iulius $
+/*  $Revision: 1.4 $
 **
 */
-
-#include "config.h"
+#include <stdio.h>
+#include <sys/types.h>
+#include "configdata.h"
 #include "clibrary.h"
-#include "inn/libinn.h"
+#include "macros.h"
 
 #ifdef HAVE_GETRUSAGE
 
-#ifdef HAVE_SYS_TIME_H
-# include <sys/time.h>
-#endif
-#include <time.h>
+#include <sys/time.h>
 #include <sys/resource.h>
 
 #define TIMEVALasDOUBLE(t)	\
