@@ -1,4 +1,4 @@
-/*  $Id: commands.c,v 1.40.2.2 2000/10/01 22:56:09 kondou Exp $
+/*  $Id: commands.c,v 1.40.2.3 2002/01/22 02:35:49 vinocur Exp $
 **
 **  Miscellaneous commands.
 */
@@ -90,6 +90,7 @@ PERMgeneric(av, accesslist)
     PERMcanread = FALSE;
     PERMcanpost = FALSE;
     PERMaccessconf->locpost = FALSE;
+    PERMaccessconf->allowapproved = FALSE;
 
     if (!*av) {
 	Reply("%d no authenticator\r\n", NNTP_SYNTAX_VAL);
@@ -194,6 +195,7 @@ PERMgeneric(av, accesslist)
     PERMcanpost = strchr(fields[1], 'P') != NULL;
     PERMaccessconf->locpost = strchr(fields[1], 'L') != NULL;
     if (strchr(fields[1], 'N') != NULL) PERMaccessconf->allownewnews = TRUE;
+    PERMaccessconf->allowapproved = strchr(fields[1], 'A') != NULL;
     sprintf(PERMuser, "%s@%s", fields[2], fields[0]);
     (void)strcpy(PERMpass, fields[3]);
     (void)strcpy(accesslist, fields[4]);
