@@ -1,4 +1,4 @@
-/*  $Revision: 1.78.2.20 $
+/*  $Revision: 1.78.2.24 $
 **
 **  NNTP server for readers (NNRP) for InterNetNews.
 **  This server doesn't do any real load-limiting, except for what has
@@ -73,7 +73,8 @@ char	*NEWSGROUPS = NULL;
 char	*NNRPACCESS = NULL;
 
 BOOL	ForceReadOnly = FALSE;
-char 	LocalLogFileName[256];
+STATIC	char 	*LocalLogFileName = NULL;
+STATIC	char 	*LocalLogDirName;
 
 STATIC double	STATstart;
 STATIC double	STATfinish;
@@ -112,7 +113,7 @@ extern FUNCTYPE	CMD_unimp();
 extern FUNCTYPE	CMDstarttls();
 #endif
 
-int LLOGenable;
+BOOL LLOGenable;
 extern int TrackClient();
 
 STATIC char	CMDfetchhelp[] = "[MessageID|Number]";
@@ -235,6 +236,9 @@ ExitWithStats(int x, BOOL readconf)
     }
 #endif	/* DO_PYTHON */
 
+    if (LocalLogFileName != NULL);
+	DISPOSE(LocalLogFileName);
+
     exit(x);
 }
 
@@ -770,7 +774,7 @@ main(int argc, char *argv[])
     /* Parse arguments.   Must COPY() optarg if used because the
      * TITLEset() routine would clobber it! */
     Reject = NULL;
-    LLOGenable=FALSE;
+    LLOGenable = FALSE;
     GRPcur = NULL;
     MaxBytesPerSecond = 0;
     strcpy(Username, "unknown");
@@ -888,7 +892,7 @@ main(int argc, char *argv[])
 		syslog(L_FATAL, "nnrpd %s must have group %s", innconf->pathrun, NEWSGRP);
 		exit(1);
 	    } else if (pwd->pw_uid != Sb.st_uid) {
-		syslog(L_FATAL, "nnrpd % must be owned by %s", innconf->pathrun, NEWSUSER);
+		syslog(L_FATAL, "nnrpd %s must be owned by %s", innconf->pathrun, NEWSUSER);
 		exit(1);
 	    }
 
@@ -961,7 +965,7 @@ main(int argc, char *argv[])
 	    if (fd < 0)
 		continue;
 	    
-	    for (i = 0; (pid = fork()) < 0; i++) {
+	    for (i = 0; i <= MAX_FORKS && (pid = fork()) < 0; i++) {
 		if (i == MAX_FORKS) {
 		    syslog(L_FATAL, "cant fork (dropping connection): %m");
 		    continue;
@@ -1014,7 +1018,7 @@ main(int argc, char *argv[])
     if (initialSSL) {
       sasl_config_read();
       ssl_result=tls_init_serverengine(5,        /* depth to verify */
-				       1,        /* can client auth? */
+				       0,        /* can client auth? */
 				       0,        /* required client to auth? */
 				       (char *)sasl_config_getstring("tls_ca_file", ""),
 				       (char *)sasl_config_getstring("tls_ca_path", ""),
@@ -1084,19 +1088,28 @@ main(int argc, char *argv[])
     }
 
     if (PERMaccessconf && PERMaccessconf->readertrack || !PERMaccessconf && innconf->readertrack) {
+	int len;
 	syslog(L_NOTICE, "%s Tracking Enabled (%s)", ClientHost, Username);
 	pid=getpid();
 	gettimeofday(&tv,NULL);
 	count += pid;
 	vid = tv.tv_sec ^ tv.tv_usec ^ pid ^ count;
-	sprintf(LocalLogFileName, "%s/tracklogs/log-%ld", innconf->pathlog,vid);
-	if ((locallog=fopen(LocalLogFileName, "w")) != NULL) {
-		syslog(L_NOTICE, "%s Local Logging begins (%s) %s",ClientHost, Username, LocalLogFileName);
-		fprintf(locallog, "%s Tracking Enabled (%s)\n", ClientHost, Username);
-		fflush(locallog);
-		LLOGenable=TRUE;
+	len = strlen("innconf->pathlog") + strlen("/tracklogs/log-") + BUFSIZ;
+	LocalLogFileName = NEW(char, len);
+	sprintf(LocalLogFileName, "%s/tracklogs/log-%ld", innconf->pathlog, vid);
+	if ((locallog = fopen(LocalLogFileName, "w")) == NULL) {
+	    LocalLogDirName = NEW(char, len);
+	    sprintf(LocalLogDirName, "%s/tracklogs", innconf->pathlog);
+	    MakeDirectory(LocalLogDirName, FALSE);
+	    DISPOSE(LocalLogDirName);
+	}
+	if (locallog == NULL && (locallog = fopen(LocalLogFileName, "w")) == NULL) {
+	    syslog(L_ERROR, "%s Local Logging failed (%s) %s: %m", ClientHost, Username, LocalLogFileName);
 	} else {
-		syslog(L_NOTICE, "%s Local Logging failed (%s) %s", ClientHost, Username, LocalLogFileName);
+	    syslog(L_NOTICE, "%s Local Logging begins (%s) %s",ClientHost, Username, LocalLogFileName);
+	    fprintf(locallog, "%s Tracking Enabled (%s)\n", ClientHost, Username);
+	    fflush(locallog);
+	    LLOGenable = TRUE;
 	}
     }
 
