@@ -1,4 +1,4 @@
-/*  $Revision: 1.36.2.4 $
+/*  $Revision: 1.36.2.7 $
 **
 **  Net News Reading Protocol server.
 */
@@ -65,6 +65,7 @@ typedef struct _ACCESSGROUP {
     char *users; 
     int allownewnews;
     int locpost;
+    int allowapproved;
     int used;
     int localtime;
     int strippath;               
@@ -191,7 +192,7 @@ extern char		*Glom();
 extern int		Argify();
 extern NORETURN		ExitWithStats(int x, BOOL readconf);
 extern BOOL		GetGroupList();
-extern char		*GetHeader();
+extern char		*GetHeader(char *header, BOOL IsLineS);
 extern void		GRPreport();
 extern void		HIScheck();
 extern char		*HISgetent();
