@@ -1,4 +1,4 @@
-/*  $Id: perm.c,v 1.17.2.7 2001/01/10 16:06:40 kondou Exp $
+/*  $Id: perm.c,v 1.17.2.13 2002/01/31 03:48:17 vinocur Exp $
 **
 **  How to figure out where a user comes from, and what that user can do once
 **  we know who sie is.
@@ -404,22 +404,29 @@ static ACCESSGROUP *copy_accessgroup(ACCESSGROUP *orig)
 
 void SetDefaultAccess(ACCESSGROUP *curaccess)
 {
-    curaccess->allownewnews = innconf->allownewnews;;
+    curaccess->allownewnews = innconf->allownewnews;
     curaccess->locpost = FALSE;
+    curaccess->allowapproved = FALSE;
     curaccess->localtime = FALSE;
     curaccess->strippath = FALSE;
     curaccess->nnrpdperlfilter = TRUE;
     curaccess->nnrpdpythonfilter = TRUE;
+    curaccess->fromhost = NULL;
     if (innconf->fromhost)
 	curaccess->fromhost = COPY(innconf->fromhost);
+    curaccess->pathhost = NULL;
     if (innconf->pathhost)
 	curaccess->pathhost = COPY(innconf->pathhost);
+    curaccess->organization = NULL;
     if (innconf->organization)
 	curaccess->organization = COPY(innconf->organization);
+    curaccess->moderatormailer = NULL;
     if (innconf->moderatormailer)
 	curaccess->moderatormailer = COPY(innconf->moderatormailer);
+    curaccess->domain = NULL;
     if (innconf->domain)
 	curaccess->domain = COPY(innconf->domain);
+    curaccess->complaints = NULL;
     if (innconf->complaints)
 	curaccess->complaints = COPY(innconf->complaints);
     curaccess->spoolfirst = innconf->spoolfirst;
@@ -434,6 +441,7 @@ void SetDefaultAccess(ACCESSGROUP *curaccess)
     curaccess->nnrpdpostport = innconf->nnrpdpostport;
     curaccess->nnrpdoverstats = innconf->nnrpdoverstats;
     curaccess->backoff_auth = innconf->backoff_auth;
+    curaccess->backoff_db = NULL;
     if (innconf->backoff_db)
 	curaccess->backoff_db = COPY(innconf->backoff_db);
     curaccess->backoff_k = innconf->backoff_k;
@@ -743,6 +751,7 @@ static void accessdecl_parse(ACCESSGROUP *curaccess, CONFFILE *f, CONFTOKEN *tok
 	    curaccess->post = 0;
 	    CLEAR_CONFIG(PERMpost);
 	}
+	curaccess->allowapproved = (strchr(tok->name, 'A') != NULL);
 	curaccess->allownewnews = (strchr(tok->name, 'N') != NULL);
 	curaccess->locpost = (strchr(tok->name, 'L') != NULL);
 	SET_CONFIG(oldtype);
@@ -1701,7 +1710,7 @@ typedef void (*LineFunc)(char*);
 /* messages from a program's stdout */
 static void HandleProgLine(char *ln)
 {
-    if (!strncmp(ln, "User:", strlen("User:")))
+    if (caseEQn(ln, "User:", strlen("User:")))
 	strcpy(ubuf, ln+strlen("User:"));
 }
 
@@ -1862,7 +1871,7 @@ static char *ResolveUser(AUTHGROUP *auth)
 	    GetProgInput(foo);
 	    done = (ubuf[0] != '\0');
 	    if (done)
-		syslog(L_TRACE, "%s res resolver succesful, user %s", ClientHost, ubuf);
+		syslog(L_TRACE, "%s res resolver successful, user %s", ClientHost, ubuf);
 	    else
 		syslog(L_TRACE, "%s res resolver failed", ClientHost);
 	    DISPOSE(foo);
@@ -1933,7 +1942,7 @@ static char *AuthenticateUser(AUTHGROUP *auth, char *username, char *password)
 	    GetProgInput(foo);
 	    done = (ubuf[0] != '\0');
 	    if (done)
-		syslog(L_TRACE, "%s auth authenticator succesful, user %s", ClientHost, ubuf);
+		syslog(L_TRACE, "%s auth authenticator successful, user %s", ClientHost, ubuf);
 	    else
 		syslog(L_TRACE, "%s auth authenticator failed", ClientHost);
 	    DISPOSE(foo);
