@@ -1,4 +1,4 @@
-/*  $Revision: 1.50.2.5 $
+/*  $Revision: 1.50.2.10 $
 **
 **  Check article, send it to the local server.
 */
@@ -357,24 +357,22 @@ ProcessHeaders(int linecount, char *idbuff)
     }
 
     if (PERMaccessconf->nnrpdauthsender) {
-	/* If authorized and we didn't get a sender, add the header based on
-	 * our info.  If not authorized, zap the Sender so we don't put out
-	 * unauthenticated data. */
-	if (PERMauthorized && HDR(_sender) == NULL) {
+	/* If authorized, add the header based on our info.  If not
+         * authorized, zap the Sender so we don't put out unauthenticated
+         * data. */
+	if (PERMauthorized) {
 	    if (PERMuser[0] == '\0') {
 		(void)sprintf(sendbuff, "%s@%s", "UNKNOWN", ClientHost);
 	    } else {
 		if ((p = strchr(PERMuser, '@')) == NULL) {
 		    (void)sprintf(sendbuff, "%s@%s", PERMuser, ClientHost);
 		} else {
-		    *p = '\0';
-		    (void)sprintf(sendbuff, "%s@%s", PERMuser, ClientHost);
-		    *p = '@';
+		    (void)sprintf(sendbuff, "%s", PERMuser);
 		}
 	    }
 	    HDR(_sender) = sendbuff;
 	}
-	else if (!PERMauthorized)
+	else
 	    HDR(_sender) = NULL;
     }
 
@@ -720,7 +718,9 @@ STATIC STRING ValidNewsgroups(char *hdr, char **modgroup)
 #endif /* DO_PYTHON */
 	    break;
 	case NF_FLAG_MODERATED:
-	    if (!approved && !*modgroup) {
+	    if (approved && !PERMaccessconf->allowapproved) {
+		(void)sprintf(Error, "You are not allowed to approve postings");
+	    } else if (!approved && !*modgroup) {
 		*modgroup = COPY(p);
 	    }
 	    break;
@@ -926,13 +926,12 @@ ARTpost(article, idbuff)
     char		buff[NNTP_STRLEN + 2], frombuf[SMBUF];
     char		*modgroup = NULL;
     STRING		error;
-    char		TrackID[NNTP_STRLEN];
+    char		*TrackID;
+    char		*DirTrackID;
     FILE		*ftd;
-    int			result;
+    int			result, len;
     char		SDir[255];
 
-    sprintf(TrackID,"%s/trackposts/track.", innconf->pathlog);
-
     /* Set up the other headers list. */
     if (OtherHeaders == NULL) {
 	OtherSize = HEADER_DELTA;
@@ -1119,8 +1118,16 @@ ARTpost(article, idbuff)
 		(void)fprintf(ToServer, "%s: %s\r\n", hp->Name, hp->Value);
 	    }
 	}
-    for (i = 0; i < OtherCount; i++)
-	(void)fprintf(ToServer, "%s\r\n", OtherHeaders[i]);
+    for (i = 0; i < OtherCount; i++) {
+	if (strchr(OtherHeaders[i], '\n') != NULL) {
+	    if ((p = Towire(OtherHeaders[i])) != NULL) {
+		(void)fprintf(ToServer, "%s\r\n", p);
+		DISPOSE(p);
+	    }
+	} else {
+	    (void)fprintf(ToServer, "%s\r\n", OtherHeaders[i]);
+	}
+    }
     (void)fprintf(ToServer, "\r\n");
     if (FLUSH_ERROR(ToServer)) {
 	(void)sprintf(Error, CANTSEND, "headers", strerror(errno));
@@ -1154,34 +1161,48 @@ ARTpost(article, idbuff)
 
     /* Tracking */
     if (PERMaccessconf->readertrack) {
-	strcat(TrackID,HDR(_messageid));
-	if ((ftd=fopen(TrackID,"w")) != NULL) {
-		for (hp = Table; hp < ENDOF(Table); hp++)
-			if (hp->Value) {
-			    if (strchr(hp->Value, '\n') != NULL) {
-				if ((p = Towire(hp->Value)) != NULL) {
-				    (void)fprintf(ftd, "%s: %s\r\n", hp->Name, p);
-				    DISPOSE(p);
-				}
-			    }
-			} else {
-			    (void)fprintf(ToServer, "%s: %s\r\n", hp->Name, hp->Value);
-			}
-		for (i=0; i<OtherCount; i++)
-			(void)fprintf(ftd,"%s\r\n",OtherHeaders[i]);
-		(void)fprintf(ftd,"\r\n");
-		result=fputs(article,ftd);
-		fclose(ftd);
-		if (result != EOF) {
-			syslog(L_NOTICE, "%s (%s) posttrack ok %s",
-				ClientHost, Username, TrackID);
-			if (LLOGenable)
-				fprintf(locallog, "%s (%s) posttrack ok %s\n",
-					ClientHost, Username, TrackID);
-		} else 
-			syslog(L_NOTICE, "%s (%s) posttrack error 2 %s",
-				ClientHost, Username, TrackID);
+	len = strlen(innconf->pathlog) + strlen("/trackposts/track.") + strlen(HDR(_messageid)) + 1;
+	TrackID = NEW(char, len);
+	sprintf(TrackID, "%s/trackposts/track.%s", innconf->pathlog, HDR(_messageid));
+	if ((ftd = fopen(TrackID,"w")) == NULL) {
+	    DirTrackID = NEW(char, len);
+	    sprintf(DirTrackID, "%s/trackposts", innconf->pathlog, HDR(_messageid));
+	    MakeDirectory(DirTrackID, FALSE);
+	    DISPOSE(DirTrackID);
 	}
+	if (ftd == NULL && (ftd = fopen(TrackID,"w")) == NULL) {
+	    syslog(L_ERROR, "%s (%s) open %s: %m",
+		ClientHost, Username, TrackID);
+	    DISPOSE(TrackID);
+	    return NULL;
+	}
+	for (hp = Table; hp < ENDOF(Table); hp++)
+	    if (hp->Value) {
+		if (strchr(hp->Value, '\n') != NULL) {
+		    if ((p = Towire(hp->Value)) != NULL) {
+			(void)fprintf(ftd, "%s: %s\r\n", hp->Name, p);
+			DISPOSE(p);
+		    }
+		} else {
+		    (void)fprintf(ftd, "%s: %s\r\n", hp->Name, hp->Value);
+		}
+	    }
+	for (i=0; i<OtherCount; i++)
+	    (void)fprintf(ftd,"%s\r\n",OtherHeaders[i]);
+	(void)fprintf(ftd,"\r\n");
+	(void)NNTPsendarticle(article, ftd, TRUE);
+	fclose(ftd);
+	if (result != EOF) {
+	    syslog(L_NOTICE, "%s (%s) posttrack ok %s",
+		ClientHost, Username, TrackID);
+	    if (LLOGenable)
+		fprintf(locallog, "%s (%s) posttrack ok %s\n",
+		    ClientHost, Username, TrackID);
+	} else {
+	    syslog(L_ERROR, "%s (%s) posttrack error 2 %s",
+		ClientHost, Username, TrackID);
+	}
+	DISPOSE(TrackID);
     }
 
     return NULL;
