@@ -1,4 +1,4 @@
-/*  $Id: cnfs.c,v 1.73.2.6 2001/03/29 01:04:13 kondou Exp $
+/*  $Id: cnfs.c,v 1.73.2.8 2001/09/21 15:11:12 kondou Exp $
 **
 **  Cyclic News File System.
 */
@@ -351,6 +351,11 @@ STATIC BOOL CNFSparse_part_line(char *l) {
     return FALSE;
   }
   *p = '\0';
+  if (CNFSgetcycbuffbyname(l) != NULL) {
+    *p = ':';
+    syslog(L_ERROR, "%s: duplicate cycbuff name in line '%s'", LocalLogName, l);
+    return FALSE;
+  }
   cycbuff = NEW(CYCBUFF, 1);
   memset(cycbuff->name, '\0', CNFSNASIZ);
   strcpy(cycbuff->name, l);
@@ -366,7 +371,7 @@ STATIC BOOL CNFSparse_part_line(char *l) {
   memset(cycbuff->path, '\0', CNFSPASIZ);
   strcpy(cycbuff->path, l);
   if (stat(cycbuff->path, &sb) < 0) {
-    syslog(L_ERROR, "%s: file '%s' does not exist, ignoring '%s' cycbuff",
+    syslog(L_ERROR, "%s: file '%s' : %m, ignoring '%s' cycbuff",
 	   LocalLogName, cycbuff->path, cycbuff->name);
     DISPOSE(cycbuff);
     return FALSE;
@@ -419,6 +424,11 @@ STATIC BOOL CNFSparse_metapart_line(char *l) {
     return FALSE;
   }
   *p = '\0';
+  if (CNFSgetmetacycbuffbyname(l) != NULL) {
+    *p = ':';
+    syslog(L_ERROR, "%s: duplicate metabuff name in line '%s'", LocalLogName, l);
+    return FALSE;
+  }
   metacycbuff = NEW(METACYCBUFF, 1);
   metacycbuff->members = (CYCBUFF **)NULL;
   metacycbuff->count = 0;
