@@ -1,4 +1,4 @@
-/*  $Id: interface.c,v 1.45.2.6 2001/03/26 22:41:43 kondou Exp $
+/*  $Id: interface.c,v 1.45.2.7 2002/04/01 08:22:32 rra Exp $
 **
 **  Storage Manager interface
 */
@@ -650,6 +650,7 @@ static BOOL MatchGroups(const char *g, int num, char **patterns) {
     const char          *p;
     int                 i;
     BOOL                wanted = FALSE;
+    BOOL                poisoned = FALSE;
 
     /* Find the end of the line */
     for (p = g+1; (*p != '\n') && (*(p - 1) != '\r'); p++);
@@ -668,19 +669,27 @@ static BOOL MatchGroups(const char *g, int num, char **patterns) {
 	for (i = 0; i < num; i++) {
 	    switch (patterns[i][0]) {
 	    case '!':
-		if (!wanted && wildmat(group, &patterns[i][1]))
-		    break;
+		if (wildmat(group, &patterns[i][1]))
+                    wanted = FALSE;
+                break;
 	    case '@':
 		if (wildmat(group, &patterns[i][1])) {
-		    DISPOSE(groups);
-		    return FALSE;
+                    wanted = FALSE;
+                    poisoned = TRUE;
 		}
 		break;
 	    default:
-		if (wildmat(group, patterns[i]))
+		if (wildmat(group, patterns[i])) {
 		    wanted = TRUE;
+                    poisoned = FALSE;
+                }
+                break;
 	    }
 	}
+        if (poisoned) {
+            DISPOSE(groups);
+            return FALSE;
+        }
     }
 
     DISPOSE(groups);
