@@ -1,4 +1,4 @@
-/*  $Id: interface.h,v 1.15.2.1 2000/09/05 23:24:23 kondou Exp $
+/*  $Id: interface.h,v 1.15.2.2 2001/02/03 07:27:27 rra Exp $
 **
 **  Storage Manager interface header
 */
@@ -8,6 +8,7 @@
 
 #include <configdata.h>
 #include <storage.h>
+#include <stdio.h>
 
 typedef struct {
     BOOL	selfexpire;
@@ -25,6 +26,7 @@ typedef struct {
     BOOL                (*cancel)(TOKEN token);
     BOOL                (*ctl)(PROBETYPE type, TOKEN *token, void *value);
     BOOL                (*flushcacheddata)(FLUSHTYPE type);
+    void                (*printfiles)(FILE *, TOKEN, char **xref, int ngroups);
     void                (*shutdown)(void);
 } STORAGE_METHOD;
 
