@@ -406,7 +406,7 @@ BOOL OVctl(OVCTLTYPE type, void *val) {
 	OVdelayrm = ((OVGE *)val)->delayrm;
 	OVusepost = ((OVGE *)val)->usepost;
 	OVrealnow = ((OVGE *)val)->now;
-	OVnow = ((OVGE *)val)->now + (time_t)(((OVGE *)val)->timewarp * 86400.);
+	OVnow = ((OVGE *)val)->now + (time_t)((OVGE *)val)->timewarp;
 	OVquiet = ((OVGE *)val)->quiet;
 	OVkeep = ((OVGE *)val)->keep;
 	OVearliest = ((OVGE *)val)->earliest;
@@ -828,9 +828,6 @@ STATIC NEWSGROUP *EXPnotfound(char *Entry)
 	bg->Name = COPY(Entry);
 	bg->Next = EXPbadgroups;
 	EXPbadgroups = bg;
-	(void)fflush(stdout);
-	(void)fprintf(stderr, "Group not matched (removed?) %s -- %s\n",
-	    Entry, "Purging all articles");
     }
     /* remove it all now. */
     if (Removeit.Keep == 0) {
@@ -850,15 +847,8 @@ STATIC enum KRP EXPkeepit(char *Entry, time_t when, time_t expires)
     NEWSGROUP	        *ngp;
     enum KRP		retval = Remove;
 
-    if ((p = strchr(Entry, ':')) == NULL) {
-	(void)fflush(stdout);
-	(void)fprintf(stderr, "Bad entry, \"%s\"\n", Entry);
-	return Remove;
-    }
-    *p = '\0';
     if ((ngp = NGfind(Entry)) == NULL)
 	ngp = EXPnotfound(Entry);
-    /* '\0' is left to get newsgroup name later */
 
     /* Bad posting date? */
     if (when > OVrealnow + 86400) {
@@ -886,23 +876,23 @@ STATIC enum KRP EXPkeepit(char *Entry, time_t when, time_t expires)
 
 /*
 **  An article can be removed.  Either print a note, or actually remove it.
-**  Also fill in the article size.
+**  Takes in the Xref information so that it can pass this to the storage
+**  API callback used to generate the list of files to remove.
 */
-void OVEXPremove(TOKEN token, BOOL deletedgroups)
+void OVEXPremove(TOKEN token, BOOL deletedgroups, char **xref, int ngroups)
 {
     EXPunlinked++;
     if (deletedgroups) {
 	EXPprocessed++;
 	EXPoverindexdrop++;
     }
-    if (EXPunlinkfile) {
-	(void)fprintf(EXPunlinkfile, "%s\n", TokenToText(token));
+    if (EXPunlinkfile && xref != NULL) {
+        SMprintfiles(EXPunlinkfile, token, xref, ngroups);
 	if (!ferror(EXPunlinkfile))
 	    return;
-	(void)fprintf(stderr, "Can't write to -z file, %s\n",
-	    strerror(errno));
-	(void)fprintf(stderr, "(Will ignore it for rest of run.)\n");
-	(void)fclose(EXPunlinkfile);
+	fprintf(stderr, "Can't write to -z file, %s\n", strerror(errno));
+	fprintf(stderr, "(Will ignore it for rest of run.)\n");
+	fclose(EXPunlinkfile);
 	EXPunlinkfile = NULL;
     }
     if (!SMcancel(token) && SMerrno != SMERR_NOENT && SMerrno != SMERR_UNINIT)
@@ -1074,6 +1064,7 @@ BOOL OVgroupbasedexpire(TOKEN token, char *group, char *data, int len, time_t ar
     BOOL                poisoned;
     BOOL		keeper;
     BOOL		remove;
+    BOOL                purge;
     ARTHANDLE		*article;
     char		*Xref;
 
@@ -1102,7 +1093,7 @@ BOOL OVgroupbasedexpire(TOKEN token, char *group, char *data, int len, time_t ar
 	if (Group != NULL) {
 	    DISPOSE(Group);
 	}
-	Group = NEW(char, strlen(group) + 1);
+	Group = NEW(char, strlen(group) + 2);
 	strcpy(Group, group);
 	strcat(Group, ":");
 	Xref = Group;
@@ -1117,33 +1108,59 @@ BOOL OVgroupbasedexpire(TOKEN token, char *group, char *data, int len, time_t ar
 	EXPoverindexdrop++;
 	return TRUE;
     }
+
+    /* arts is now an array of strings, each of which is a group name, a
+       colon, and an article number.  EXPkeepit wants just pure group names,
+       so replace the colons with nuls (deleting the overview entry if it
+       isn't in the expected form). */
+    for (i = 0; i < count; i++) {
+        p = strchr(arts[i], ':');
+        if (p == NULL) {
+            fflush(stdout);
+            fprintf(stderr, "Bad entry, \"%s\"\n", arts[i]);
+            EXPoverindexdrop++;
+            return TRUE;
+        }
+        *p = '\0';
+    }
+
     /* First check all postings */
     poisoned = FALSE;
     keeper = FALSE;
     remove = FALSE;
+    purge = TRUE;
     for (i = 0; i < count; ++i) {
 	if ((krps[i] = EXPkeepit(arts[i], when, expires)) == Poison)
 	    poisoned = TRUE;
 	if (OVkeep && (krps[i] == Keep))
 	    keeper = TRUE;
-	if ((krps[i] == Remove))
+	if ((krps[i] == Remove) && EQ(group, arts[i]))
 	    remove = TRUE;
+        if ((krps[i] == Keep))
+            purge = FALSE;
     }
     EXPprocessed++;
 
     if (OVearliest) {
 	if (remove || poisoned || token.type == TOKEN_EMPTY) {
-	    if (strcmp(group, arts[0]) == 0)
-		/* delete article if this is first entry */
-		OVEXPremove(token, FALSE);
+	    /* delete article if this is first entry */
+	    if (EQ(group, arts[0])) {
+		for (i = 0; i < count; i++)
+		    arts[i][strlen(arts[i])] = ':';
+		OVEXPremove(token, FALSE, arts, count);
+	    }
 	    EXPoverindexdrop++;
 	    return TRUE;
 	}
     } else { /* not earliest mode */
-	if (!keeper || token.type == TOKEN_EMPTY) {
-	    if (strcmp(group, arts[0]) == 0)
-		/* delete article if this is first entry */
-		OVEXPremove(token, FALSE);
+	if ((!keeper && remove) || token.type == TOKEN_EMPTY) {
+	    /* delete article if purge is set, indicating that it has
+	       expired out of every group to which it was posted */
+	    if (purge) {
+		for (i = 0; i < count; i++)
+		    arts[i][strlen(arts[i])] = ':';
+		OVEXPremove(token, FALSE, arts, count);
+	    }
 	    EXPoverindexdrop++;
 	    return TRUE;
 	}
