@@ -1,4 +1,4 @@
-/*  $Id: tradspool.c,v 1.23.2.4 2001/02/03 07:28:09 rra Exp $
+/*  $Id: tradspool.c,v 1.23.2.9 2002/02/11 17:31:45 vinocur Exp $
 **
 **  Storage manager module for traditional spool format.
 */
@@ -29,11 +29,11 @@
 typedef struct {
     char		*artbase; /* start of the article data -- may be mmaped */
     unsigned int	artlen; /* art length. */
-    int 	nextindex;
+    int		nextindex;
     char		*curdirname;
     DIR			*curdir;
     struct _ngtent	*ngtp;
-    BOOL 		mmapped;
+    BOOL		mmapped;
 } PRIV_TRADSPOOL;
 
 /*
@@ -410,13 +410,13 @@ InitNGTable(void) {
 #define RELOAD_TIME_CHECK 600
 
 void
-CheckNeedReloadDB(void) {
+CheckNeedReloadDB(BOOL force) {
     static TIMEINFO lastcheck, oldlastcheck, now;
     struct stat sb;
     char *fname;
 
     if (GetTimeInfo(&now) < 0) return; /* anyone ever seen gettimeofday fail? :-) */
-    if (lastcheck.time + RELOAD_TIME_CHECK > now.time) return;
+    if (!force && lastcheck.time + RELOAD_TIME_CHECK > now.time) return;
 
     oldlastcheck = lastcheck;
     lastcheck = now;
@@ -427,7 +427,7 @@ CheckNeedReloadDB(void) {
 	return;
     }
     DISPOSE(fname);
-    if (sb.st_mtime > oldlastcheck.time && oldlastcheck.time != 0) {
+    if (sb.st_mtime > oldlastcheck.time) {
 	/* add any newly added ngs to our in-memory copy of the db. */
 	ReadDBFile();
     }
@@ -487,7 +487,7 @@ TokenToPath(TOKEN token) {
     unsigned long artnum;
     char *ng, *path;
 
-    CheckNeedReloadDB(); 
+    CheckNeedReloadDB(FALSE);
 
     memcpy(&ngnum, &token.token[0], sizeof(ngnum));
     memcpy(&artnum, &token.token[sizeof(ngnum)], sizeof(artnum));
@@ -495,7 +495,12 @@ TokenToPath(TOKEN token) {
     ngnum = ntohl(ngnum);
 
     ng = FindNGByNum(ngnum);
-    if (ng == NULL) return NULL;
+    if (ng == NULL) {
+	CheckNeedReloadDB(TRUE);
+	ng = FindNGByNum(ngnum);
+	if (ng == NULL)
+	    return NULL;
+    }
 
     path = NEW(char, strlen(ng)+20+strlen(innconf->patharticles));
     sprintf(path, "%s/%s/%lu", innconf->patharticles, ng, artnum);
@@ -547,7 +552,7 @@ CrackXref(char *xref, unsigned int *lenp) {
 	    RENEW(xrefs, char *, xrefsize);
 	}
 
- 	p = q;
+	p = q;
 	/* skip spaces */
 	for ( ; *p == ' ' ; p++) ;
     }
@@ -883,7 +888,10 @@ tradspool_retrieve(const TOKEN token, const RETRTYPE amount) {
 	return NULL;
     }
 
-    if ((path = TokenToPath(token)) == NULL) return NULL;
+    if ((path = TokenToPath(token)) == NULL) {
+	SMseterror(SMERR_NOENT, NULL);
+	return NULL;
+    }
     if ((art = OpenArticle(path, amount)) != (ARTHANDLE *)NULL) {
         ret_token = token;
         art->token = &ret_token;
@@ -971,11 +979,16 @@ tradspool_cancel(TOKEN token) {
 
 	linkpath = NEW(char, strlen(innconf->patharticles) + strlen(ng) + 32);
 	sprintf(linkpath, "%s/%s/%lu", innconf->patharticles, ng, artnum);
-	/* hmm, do we want to abort this if one of the symlink unlinks fails? */
-	if (unlink(linkpath) < 0) result = FALSE;
+	/* repeated unlinkings of a crossposted article may fail on account
+	   of the file no longer existing without it truly being an error */
+	if (unlink(linkpath) < 0)
+	    if (errno != ENOENT || i == 1)
+		result = FALSE;
 	DISPOSE(linkpath);
     }
-    if (unlink(path) < 0) result = FALSE;
+    if (unlink(path) < 0)
+	if (errno != ENOENT || numxrefs == 1)
+	    result = FALSE;
     DISPOSE(path);
     for (i = 0 ; i < numxrefs ; ++i) DISPOSE(xrefs[i]);
     DISPOSE(xrefs);
@@ -1208,13 +1221,18 @@ BOOL tradspool_ctl(PROBETYPE type, TOKEN *token, void *value) {
     case SMARTNGNUM:
 	if ((ann = (struct artngnum *)value) == NULL)
 	    return FALSE;
-	CheckNeedReloadDB();
+	CheckNeedReloadDB(FALSE);
 	memcpy(&ngnum, &token->token[0], sizeof(ngnum));
 	memcpy(&artnum, &token->token[sizeof(ngnum)], sizeof(artnum));
 	artnum = ntohl(artnum);
 	ngnum = ntohl(ngnum);
 	ng = FindNGByNum(ngnum);
-	if (ng == NULL) return FALSE;
+	if (ng == NULL) {
+	    CheckNeedReloadDB(TRUE);
+	    ng = FindNGByNum(ngnum);
+	    if (ng == NULL)
+		return FALSE;
+	}
 	ann->groupname = COPY(ng);
 	ann->artnum = (ARTNUM)artnum;
 	return TRUE;
